<?php
/**
 * @file
 * Entity API
 */
/**
 * Create a site notice object.
 */
function site_notice_create($values = array()) {
  return entity_create('site_notice', $values);
}

/**
 * Load a site notice.
 */
function site_notice_load($snid, $reset = FALSE) {
  $notices = site_notice_load_multiple(array($snid), array(), $reset);
  return reset($notices);
}

/**
 * Load multiple notices based on certain conditions.
 */
function site_notice_load_multiple($snids = array(), $conditions = array(), $reset = FALSE) {
  return entity_load('site_notice', $snids, $conditions, $reset);
}

/**
* Save site notice.
*/
function site_notice_save($notice) {
  entity_save('site_notice', $notice);
}

/**
* Delete single site notice.
*/
function site_notice_delete($notice) {
  entity_delete('site_notice', entity_id('site_notice', $notice));
}

/**
* Delete multiple site notices.
*/
function site_notice_delete_multiple($notice) {
  entity_delete_multiple('site_notice', $notice);
}

/**
 * Sets up content to show an individual notice
 * @todo - get rid of drupal_set_title();
 */
function site_notice_page_view($notice, $view_mode = 'full') {
  $controller = entity_get_controller('site_notice');
  $content = $controller->view(array($notice->snid => $notice));
  drupal_set_title($notice->title);
  return $content;
}

/*******************************************************************************
 * Entity and Controller
 ******************************************************************************/
/**
 * Site Notice class.
 */
class SiteNoticeEntity extends Entity {
  const DISABLED = 0;
  const TOP      = 1;
  const BOTTOM   = 2;

  const FILTER_EXCLUDE = 0;
  const FILTER_INCLUDE = 1;

  protected function defaultLabel() {
    return $this->title;
  }
  protected function defaultUri() {
    return array('path' => 'site-notices/' . $this->identifier());
  }

  // Save the entity
  public function save() {
    // Serialize the settings
    $this->settings = serialize($this->settings);
    return parent::save();
  }
}

/**
 * Site Notice Controller
 */
class SiteNoticeController extends EntityAPIController {
  public function create(array $values = array()) {
    global $user;
    $values += array(
      'title'    => '',
      'created'  => REQUEST_TIME,
      'changed'  => REQUEST_TIME,
      'uid'      => $user->uid,
      'language' => language_default('language'),
      'status'   => 1,
    );
    return parent::create($values);
  }

  /**
   * Overriding the buldContent function to add entity specific fields
   */
  public function buildContent($entity, $view_mode = 'full', $langcode = NULL, $content = array()) {
    $content = parent::buildContent($entity, $view_mode, $langcode, $content);
    return $content;
  }

  // Load the entity
  public function load($ids = array(), $conditions = array()) {
    $notices = parent::load($ids, $conditions);

    // Unserialize the settings
    foreach ($notices as $notice) {
      if (is_string($notice->settings)) {
        $notice->settings = unserialize($notice->settings);
      }
    }

    return $notices;
  }
}

